/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.managementcenter.activiti.web;

import com.google.common.collect.Maps;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.act.service.ActProcessService;
import com.jeeplus.modules.act.service.ActTaskService;
import com.jeeplus.modules.sg.managementcenter.activiti.entity.Construction;
import com.jeeplus.modules.sg.managementcenter.activiti.service.ConstructionService;
import com.jeeplus.modules.test.activiti.entity.OALeave;
import com.jeeplus.modules.test.activiti.service.OALeaveService;
import org.activiti.engine.repository.ProcessDefinition;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * 施工交底Controller
 * @author
 * @version 2019-11-08
 */
@Controller
@RequestMapping(value = "${adminPath}/managementcenter/activiti")

public class ConstructionController extends BaseController {

	@Autowired
	private ConstructionService constructionService;
	@Autowired
	private ActProcessService actProcessService;
	@Autowired
	private ActTaskService actTaskService;
	
	@ModelAttribute
	public Construction get(@RequestParam(required=false) String id) {
		Construction entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = constructionService.get(id);
		}
		if (entity == null){
			entity = new Construction();
		}
		return entity;
	}
	

	/**
	 * 查看，增加，编辑请假申请表单页面
	 */
	@RequestMapping(value = "form/{mode}")
	public String form(@PathVariable String mode, Construction construction, Model model) {
		model.addAttribute("construction", construction);
		if("add".equals(mode) || "edit".equals(mode)){
			return "modules/sg/managementcenter/activiti/constructionForm";
		}else{//audit
			return "modules/sg/managementcenter/activiti/constructionAudit";
		}
	}

	/**
	 * 保存请假申请
	 */
	@ResponseBody
	@RequestMapping(value = "save")
	public AjaxJson save(Construction construction, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(construction);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}


		/**
		 * 流程审批
		 */
		if (StringUtils.isBlank(construction.getId())){
			//新增或编辑表单保存
			constructionService.save(construction);//保存
			// 启动流程
			ProcessDefinition p = actProcessService.getProcessDefinition(construction.getAct().getProcDefId());
			String title = construction.getCurrentUser().getName()+"在"+ DateUtils.getDateTime()+"发起"+p.getName();
			actTaskService.startProcess(p.getKey(),  "xm_construction_clarificaiton", construction.getId(), title);
			j.setMsg("发起流程审批成功!");
			j.getBody().put("targetUrl",  "/act/task/process/");
		}else{
			//新增或编辑表单保存
			constructionService.save(construction);//保存
			construction.getAct().setComment(("yes".equals(construction.getAct().getFlag())?"[重新申请] ":"[销毁申请] "));
			// 完成流程任务
			Map<String, Object> vars = Maps.newHashMap();
			vars.put("reapply", "yes".equals(construction.getAct().getFlag())? true : false);
			actTaskService.complete(construction.getAct().getTaskId(), construction.getAct().getProcInsId(), construction.getAct().getComment(), construction.getContent(), vars);
			j.setMsg("提交成功！");
			j.getBody().put("targetUrl",  "/act/task/todo/");
		}

		return j;
	}
	


}